package org.jeecg.modules.employTrade.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.employTrade.entity.EmployTrade;
import org.jeecg.modules.employTrade.service.IEmployTradeService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 交易订单
 * @Author: jeecg-boot
 * @Date:   2025-02-22
 * @Version: V1.0
 */
@Api(tags="交易订单")
@RestController
@RequestMapping("/employTrade/employTrade")
@Slf4j
public class EmployTradeController extends JeecgController<EmployTrade, IEmployTradeService> {
	@Autowired
	private IEmployTradeService employTradeService;
	
	/**
	 * 分页列表查询
	 *
	 * @param employTrade
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "交易订单-分页列表查询")
	@ApiOperation(value="交易订单-分页列表查询", notes="交易订单-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<EmployTrade>> queryPageList(EmployTrade employTrade,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<EmployTrade> queryWrapper = QueryGenerator.initQueryWrapper(employTrade, req.getParameterMap());
		Page<EmployTrade> page = new Page<EmployTrade>(pageNo, pageSize);
		IPage<EmployTrade> pageList = employTradeService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param employTrade
	 * @return
	 */
	@AutoLog(value = "交易订单-添加")
	@ApiOperation(value="交易订单-添加", notes="交易订单-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody EmployTrade employTrade) {
		employTradeService.save(employTrade);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param employTrade
	 * @return
	 */
	@AutoLog(value = "交易订单-编辑")
	@ApiOperation(value="交易订单-编辑", notes="交易订单-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody EmployTrade employTrade) {
		employTradeService.updateById(employTrade);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "交易订单-通过id删除")
	@ApiOperation(value="交易订单-通过id删除", notes="交易订单-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		employTradeService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "交易订单-批量删除")
	@ApiOperation(value="交易订单-批量删除", notes="交易订单-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.employTradeService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "交易订单-通过id查询")
	@ApiOperation(value="交易订单-通过id查询", notes="交易订单-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<EmployTrade> queryById(@RequestParam(name="id",required=true) String id) {
		EmployTrade employTrade = employTradeService.getById(id);
		if(employTrade==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(employTrade);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param employTrade
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, EmployTrade employTrade) {
        return super.exportXls(request, employTrade, EmployTrade.class, "交易订单");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, EmployTrade.class);
    }

}
